=== modified file 'bzrlib/controldir.py'
--- bzrlib/controldir.py	2012-01-18 17:46:57 +0000
+++ bzrlib/controldir.py	2012-01-25 15:53:18 +0000
@@ -778,7 +778,8 @@
         return controldir._get_tree_branch()
 
     @classmethod
-    def open_containing_tree_or_branch(klass, location):
+    def open_containing_tree_or_branch(klass, location,
+            possible_transports=None):
         """Return the branch and working tree contained by a location.
 
         Returns (tree, branch, relpath).
@@ -787,7 +788,8 @@
         raised
         relpath is the portion of the path that is contained by the branch.
         """
-        controldir, relpath = klass.open_containing(location)
+        controldir, relpath = klass.open_containing(location,
+            possible_transports=possible_transports)
         tree, branch = controldir._get_tree_branch()
         return tree, branch, relpath
 

=== modified file 'bzrlib/send.py'
--- bzrlib/send.py	2012-01-04 17:12:42 +0000
+++ bzrlib/send.py	2012-01-25 15:53:18 +0000
@@ -41,9 +41,9 @@
 def send(target_branch, revision, public_branch, remember,
          format, no_bundle, no_patch, output, from_, mail_to, message, body,
          to_file, strict=None):
+    possible_transports = []
     tree, branch = controldir.ControlDir.open_containing_tree_or_branch(
-        from_)[:2]
-    possible_transports = [tree.bzrdir.transport, branch.bzrdir.transport]
+        from_, possible_transports=possible_transports)[:2]
     # we may need to write data into branch's repository to calculate
     # the data to send.
     branch.lock_write()

=== modified file 'bzrlib/tests/blackbox/test_send.py'
--- bzrlib/tests/blackbox/test_send.py	2012-01-04 17:12:42 +0000
+++ bzrlib/tests/blackbox/test_send.py	2012-01-25 15:53:18 +0000
@@ -24,6 +24,7 @@
     merge_directive,
     tests,
     )
+from bzrlib.controldir import ControlDir
 from bzrlib.bundle import serializer
 from bzrlib.transport import memory
 from bzrlib.tests import (
@@ -330,6 +331,10 @@
         super(TestSendStrictWithoutChanges, self).setUp()
         self.make_parent_and_local_branches()
 
+    def test_send_without_workingtree(self):
+        ControlDir.open("local").destroy_workingtree()
+        self.assertSendSucceeds([])
+
     def test_send_default(self):
         self.assertSendSucceeds([])
 

=== modified file 'doc/en/release-notes/bzr-2.5.txt'
--- doc/en/release-notes/bzr-2.5.txt	2012-01-20 16:42:27 +0000
+++ doc/en/release-notes/bzr-2.5.txt	2012-01-25 15:53:18 +0000
@@ -47,6 +47,9 @@
 * ``bzr branch`` now fetches revisions when branching into an empty
   control directory. (Jelmer Vernooij, #905594)
 
+* ``bzr send`` works on treeless branches again.
+  (Jelmer Vernooij, #921591)
+
 * Support scripts that don't call bzrlib.initialize() but still call run_bzr().
   (Vincent Ladeuil, #917733)
 

